document.addEventListener('DOMContentLoaded', () => {
  const videoForm = document.getElementById('videoForm');
  const videoUrl = document.getElementById('videoUrl');
  const languageSelect = document.getElementById('languageSelect');
  const videoPlayer = document.getElementById('videoPlayer');
  const subtitles = document.getElementById('subtitles');

  videoForm.addEventListener('submit', async (e) => {
    e.preventDefault();
    
    // Show loading state
    videoPlayer.innerHTML = '<div class="loading">Loading video...</div>';
    subtitles.innerHTML = '<div class="loading">Fetching subtitles...</div>';

    try {
      // Simulate API call for demo purposes
      await new Promise(resolve => setTimeout(resolve, 1500));
      
      // Demo response
      const response = {
        success: true,
        videoEmbed: '<iframe width="100%" height="100%" src="about:blank" frameborder="0" allowfullscreen></iframe>',
        subtitles: 'Sample subtitles would appear here in the selected language: ' + languageSelect.value
      };

      if (response.success) {
        videoPlayer.innerHTML = response.videoEmbed;
        subtitles.innerHTML = response.subtitles;
      }
    } catch (error) {
      videoPlayer.innerHTML = '<div class="error">Error loading video</div>';
      subtitles.innerHTML = '<div class="error">Error fetching subtitles</div>';
    }
  });

  // Add input validation
  videoUrl.addEventListener('input', () => {
    if (videoUrl.validity.typeMismatch) {
      videoUrl.setCustomValidity('Please enter a valid URL');
    } else {
      videoUrl.setCustomValidity('');
    }
  });

  // Add smooth scroll behavior
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
      e.preventDefault();
      document.querySelector(this.getAttribute('href')).scrollIntoView({
        behavior: 'smooth'
      });
    });
  });
});
